use utf8;
package Rechoarder::Schema::Result::Catalog;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

=head1 NAME

Rechoarder::Schema::Result::Catalog

=head1 DESCRIPTION

The catalog table has one record for each piece of media, and defines the meaningful details of that media.``

=cut

use strict;
use warnings;

use Moose;
use MooseX::NonMoose;
use MooseX::MarkAsMethods autoclean => 1;
extends 'DBIx::Class::Core';

=head1 COMPONENTS LOADED

=over 4

=item * L<DBIx::Class::InflateColumn::DateTime>

=back

=cut

__PACKAGE__->load_components("InflateColumn::DateTime");

=head1 TABLE: C<catalog>

=cut

__PACKAGE__->table("catalog");

=head1 ACCESSORS

=head2 id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'catalog_id_seq'

=head2 title

  data_type: 'varchar'
  is_nullable: 0
  size: 80

=head2 artist

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 media_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 cover_condition

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 media_condition

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 price

  data_type: 'money'
  is_nullable: 0

=head2 category

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 description

  data_type: 'varchar'
  is_nullable: 0
  size: 16000

=head2 label

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 release_number

  data_type: 'varchar'
  is_nullable: 1
  size: 10

=head2 release_date

  data_type: 'date'
  is_nullable: 1

=head2 release_country

  data_type: 'varchar'
  is_nullable: 1
  size: 10

=head2 mono_stereo

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 nrecinset

  data_type: 'integer'
  is_nullable: 0

=head2 onhand

  data_type: 'integer'
  is_nullable: 0

=head2 primary_picture

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 physical_location

  data_type: 'varchar'
  is_nullable: 1
  size: 35

=cut

__PACKAGE__->add_columns(
  "id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "catalog_id_seq",
  },
  "title",
  { data_type => "varchar", is_nullable => 0, size => 80 },
  "artist",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "media_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "cover_condition",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "media_condition",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "price",
  { data_type => "money", is_nullable => 0 },
  "category",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "description",
  { data_type => "varchar", is_nullable => 0, size => 16000 },
  "label",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "release_number",
  { data_type => "varchar", is_nullable => 1, size => 10 },
  "release_date",
  { data_type => "date", is_nullable => 1 },
  "release_country",
  { data_type => "varchar", is_nullable => 1, size => 10 },
  "mono_stereo",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "nrecinset",
  { data_type => "integer", is_nullable => 0 },
  "onhand",
  { data_type => "integer", is_nullable => 0 },
  "primary_picture",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "physical_location",
  { data_type => "varchar", is_nullable => 1, size => 35 },
);

=head1 PRIMARY KEY

=over 4

=item * L</id>

=back

=cut

__PACKAGE__->set_primary_key("id");

=head1 RELATIONS

=head2 artist

Type: belongs_to

Related object: L<Rechoarder::Schema::Result::Artist>

=cut

__PACKAGE__->belongs_to(
  "artist",
  "Rechoarder::Schema::Result::Artist",
  { id => "artist" },
  { is_deferrable => 0, on_delete => "NO ACTION", on_update => "NO ACTION" },
);

=head2 category

Type: belongs_to

Related object: L<Rechoarder::Schema::Result::Category>

=cut

__PACKAGE__->belongs_to(
  "category",
  "Rechoarder::Schema::Result::Category",
  { id => "category" },
  { is_deferrable => 0, on_delete => "NO ACTION", on_update => "NO ACTION" },
);

=head2 cover_condition

Type: belongs_to

Related object: L<Rechoarder::Schema::Result::Condition>

=cut

__PACKAGE__->belongs_to(
  "cover_condition",
  "Rechoarder::Schema::Result::Condition",
  { id => "cover_condition" },
  { is_deferrable => 0, on_delete => "NO ACTION", on_update => "NO ACTION" },
);

=head2 label

Type: belongs_to

Related object: L<Rechoarder::Schema::Result::Label>

=cut

__PACKAGE__->belongs_to(
  "label",
  "Rechoarder::Schema::Result::Label",
  { id => "label" },
  { is_deferrable => 0, on_delete => "NO ACTION", on_update => "NO ACTION" },
);

=head2 media_condition

Type: belongs_to

Related object: L<Rechoarder::Schema::Result::Condition>

=cut

__PACKAGE__->belongs_to(
  "media_condition",
  "Rechoarder::Schema::Result::Condition",
  { id => "media_condition" },
  { is_deferrable => 0, on_delete => "NO ACTION", on_update => "NO ACTION" },
);

=head2 media_type

Type: belongs_to

Related object: L<Rechoarder::Schema::Result::MediaType>

=cut

__PACKAGE__->belongs_to(
  "media_type",
  "Rechoarder::Schema::Result::MediaType",
  { id => "media_type" },
  { is_deferrable => 0, on_delete => "NO ACTION", on_update => "NO ACTION" },
);

=head2 mono_stereo

Type: belongs_to

Related object: L<Rechoarder::Schema::Result::MonoStereoType>

=cut

__PACKAGE__->belongs_to(
  "mono_stereo",
  "Rechoarder::Schema::Result::MonoStereoType",
  { id => "mono_stereo" },
  { is_deferrable => 0, on_delete => "NO ACTION", on_update => "NO ACTION" },
);

=head2 primary_picture

Type: belongs_to

Related object: L<Rechoarder::Schema::Result::Picture>

=cut

__PACKAGE__->belongs_to(
  "primary_picture",
  "Rechoarder::Schema::Result::Picture",
  { id => "primary_picture" },
  {
    is_deferrable => 0,
    join_type     => "LEFT",
    on_delete     => "NO ACTION",
    on_update     => "NO ACTION",
  },
);


# Created by DBIx::Class::Schema::Loader v0.07033 @ 2012-10-24 22:17:14
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:rliDFBDa21Bvf5kU5siuFQ

=head2 formatId

Given an ID, format it to the "public" view we want, which is LWExxxxxx.

If passed an already-formatted ID, do the right thing and work.

Returns a formatted ID or undef if it can't make one.

If called as a method, will default to the id of the object.  Scary evil!

=cut

sub formatId {
    my $self;   # Undef if called as a method
    # If this is a reference, assume it's a self
    if(ref $_[0]) {
        $self = shift;
    }
    my $id = shift;

    # If we got a self, but no ID, use the id out of ourself
    if(defined $self and not defined $id) {
        $id = $self->id;
    }

    $id = extractId($id);
    if(defined $id) {
        $id = sprintf("LWE%06.06d", $id);
    }
    return $id;
}

=head2 extractId

Given an ID or a formatted ID, return the numeric ID.

Returns a numeric ID or undef if it can't fathom the ID.

=cut

sub extractId {
    my $id = shift;

    if($id =~ /^lwe(\d+)$/i) {
        $id = $1 + 0; # Convert to an integer value
    }
    elsif($id =~ /^\d+$/) {
        $id = $id + 0; # Convert to an integer value
    }
    else {
        $id = undef;
    }
    return $id;
}

# You can replace this text with custom code or comments, and it will be preserved on regeneration
__PACKAGE__->meta->make_immutable;
1;
